Learn R Programming

dcov (version 0.1.1)

dcor.ttest: Distance correlation T-test It uses the result of U-statistic distance correlation to test independence for high dimensional data

Description

Distance correlation T-test It uses the result of U-statistic distance correlation to test independence for high dimensional data

Usage

dcor.ttest(x, y)

Arguments

x

data of x

y

data of y

Examples

Run this code
# NOT RUN {
n = 200
x = rnorm(n)
y = rnorm(n)
res = dcor.ttest(x,y)
# }

Run the code above in your browser using DataLab